# PiNatsApp


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [readonly] 
**app_name** | **str** |  | [optional] 
**json** | **dict(str, object)** | Output of &#x60;nsc describe account&#x60; | [optional] 
**pi** | **int** |  | 
**organization** | [**NatsOrganization**](NatsOrganization.md) |  | 
**organization_user** | **int** |  | 
**nats_server_uri** | **str** |  | [readonly] 
**nats_ws_uri** | **str** |  | [readonly] 
**nats_subject_pattern** | **str** |  | [readonly] 
**nats_subject_pattern_template** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


